/hg/gfx-test: Minor fixes, added new helpers methods into BitBlt...

ptisnovs at icedtea.classpath.org ptisnovs at icedtea.classpath.org
Wed May 14 08:24:27 UTC 2014


changeset 07ad90c67150 in /hg/gfx-test
details: http://icedtea.classpath.org/hg/gfx-test?cmd=changeset;node=07ad90c67150
author: Pavel Tisnovsky <ptisnovs at redhat.com>
date: Wed May 14 10:25:12 2014 +0200

	Minor fixes, added new helpers methods into BitBltUsingBgColor.


diffstat:

 ChangeLog                                          |   5 +
 src/org/gfxtest/testsuites/BitBltUsingBgColor.java |  89 +++++++++++++--------
 2 files changed, 58 insertions(+), 36 deletions(-)

diffs (325 lines):

diff -r fb641ea232c6 -r 07ad90c67150 ChangeLog
--- a/ChangeLog	Tue May 13 10:36:58 2014 +0200
+++ b/ChangeLog	Wed May 14 10:25:12 2014 +0200
@@ -1,3 +1,8 @@
+2014-05-14  Pavel Tisnovsky  <ptisnovs at redhat.com>
+
+	* src/org/gfxtest/testsuites/BitBltUsingBgColor.java:
+	Minor fixes, added new helpers methods into BitBltUsingBgColor.
+
 2014-05-13  Pavel Tisnovsky  <ptisnovs at redhat.com>
 
 	* src/org/gfxtest/testsuites/CAGOperationsOnTwoConcentricCircles.java:
diff -r fb641ea232c6 -r 07ad90c67150 src/org/gfxtest/testsuites/BitBltUsingBgColor.java
--- a/src/org/gfxtest/testsuites/BitBltUsingBgColor.java	Tue May 13 10:36:58 2014 +0200
+++ b/src/org/gfxtest/testsuites/BitBltUsingBgColor.java	Wed May 14 10:25:12 2014 +0200
@@ -82,7 +82,7 @@
 {
 
     /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_3BYTE_BGR
+     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
      *
      * @param image
      *            image to be used as a destination for BitBlt-type operations
@@ -92,14 +92,14 @@
      *            background color
      * @return test result status - PASSED, FAILED or ERROR
      */
-    private TestResult doBitBltEmptyBufferedImageType3ByteRGB(TestImage image, Graphics2D graphics2d,
+    private TestResult doBitBltEmptyBufferedImageType3ByteBGR(TestImage image, Graphics2D graphics2d,
                     Color backgroundColor)
     {
         return CommonBitmapOperations.doBitBltTestWithEmptyImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR, backgroundColor);
     }
 
     /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_4BYTE_ABGR
+     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR}.
      *
      * @param image
      *            image to be used as a destination for BitBlt-type operations
@@ -116,7 +116,7 @@
     }
 
     /**
      * Test basic BitBlt operation for empty buffered image with type TYPE_4BYTE_ABGR
      *
      * @param image
      *            image to be used as a destination for BitBlt-type operations
@@ -126,14 +126,14 @@
      *            background color
      * @return test result status - PASSED, FAILED or ERROR
      */
-    private TestResult doBitBltEmptyBufferedImageType4ByteABGRPre(TestImage image, Graphics2D graphics2d,
+    private TestResult doBitBltEmptyBufferedImageType4ByteABGR_Pre(TestImage image, Graphics2D graphics2d,
                     Color backgroundColor)
     {
         return CommonBitmapOperations.doBitBltTestWithEmptyImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE, backgroundColor);
     }
 
     /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_ARGB
+     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_INT_ARGB}.
      *
      * @param image
      *            image to be used as a destination for BitBlt-type operations
@@ -150,7 +150,7 @@
     }
 
     /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_ARGB_PRE
+     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_INT_ARGB_PRE}.
      *
      * @param image
      *            image to be used as a destination for BitBlt-type operations
@@ -160,14 +160,14 @@
      *            background color
      * @return test result status - PASSED, FAILED or ERROR
      */
-    private TestResult doBitBltEmptyBufferedImageTypeIntARGBPre(TestImage image, Graphics2D graphics2d,
+    private TestResult doBitBltEmptyBufferedImageTypeIntARGB_Pre(TestImage image, Graphics2D graphics2d,
                     Color backgroundColor)
     {
         return CommonBitmapOperations.doBitBltTestWithEmptyImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE, backgroundColor);
     }
 
     /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_BGR
+     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
      *
      * @param image
      *            image to be used as a destination for BitBlt-type operations
@@ -184,7 +184,7 @@
     }
 
     /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_RGB
+     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_INT_RGB}.
      *
      * @param image
      *            image to be used as a destination for BitBlt-type operations
@@ -201,7 +201,7 @@
     }
 
     /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_BINARY
+     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_BYTE_BINARY}.
      *
      * @param image
      *            image to be used as a destination for BitBlt-type operations
@@ -218,7 +218,7 @@
     }
 
     /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_GRAY
+     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
      *
      * @param image
      *            image to be used as a destination for BitBlt-type operations
@@ -235,7 +235,7 @@
     }
 
     /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_INDEXED
+     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_BYTE_INDEXED}.
      *
      * @param image
      *            image to be used as a destination for BitBlt-type operations
@@ -252,7 +252,7 @@
     }
 
     /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_555_RGB
+     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_USHORT_555_RGB}.
      *
      * @param image
      *            image to be used as a destination for BitBlt-type operations
@@ -269,7 +269,7 @@
     }
 
     /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_565_RGB
+     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_USHORT_565_RGB}.
      *
      * @param image
      *            image to be used as a destination for BitBlt-type operations
@@ -286,7 +286,7 @@
     }
 
     /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_GRAY
+     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_USHORT_GRAY}.
      *
      * @param image
      *            image to be used as a destination for BitBlt-type operations
@@ -303,7 +303,7 @@
     }
 
     /**
      * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR
      *
      * @param image
      *            image to be used as a destination for BitBlt-type operations
@@ -313,14 +313,14 @@
      *            background color
      * @return test result status - PASSED, FAILED or ERROR
      */
-    private TestResult doBitBltCheckerBufferedImageType3ByteRGB(TestImage image, Graphics2D graphics2d,
+    private TestResult doBitBltEmptyBufferedImageTypeCustom(TestImage image, Graphics2D graphics2d,
                     Color backgroundColor)
     {
-        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR, backgroundColor);
-    }
-
-    /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_4BYTE_ABGR
+        return CommonBitmapOperations.doBitBltTestWithEmptyImage(image, graphics2d, BufferedImage.TYPE_CUSTOM, backgroundColor);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
      *
      * @param image
      *            image to be used as a destination for BitBlt-type operations
@@ -330,6 +330,23 @@
      *            background color
      * @return test result status - PASSED, FAILED or ERROR
      */
+    private TestResult doBitBltCheckerBufferedImageType3ByteBGR(TestImage image, Graphics2D graphics2d,
+                    Color backgroundColor)
+    {
+        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR, backgroundColor);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR}.
+     *
+     * @param image
+     *            image to be used as a destination for BitBlt-type operations
+     * @param graphics2d
+     *            graphics canvas
+     * @param backgroundColor
+     *            background color
+     * @return test result status - PASSED, FAILED or ERROR
+     */
     private TestResult doBitBltCheckerBufferedImageType4ByteABGR(TestImage image, Graphics2D graphics2d,
                     Color backgroundColor)
     {
@@ -337,7 +354,7 @@
     }
 
     /**
      * Test basic BitBlt operation for checker buffered image with type TYPE_4BYTE_ABGR
      *
      * @param image
      *            image to be used as a destination for BitBlt-type operations
@@ -347,14 +364,14 @@
      *            background color
      * @return test result status - PASSED, FAILED or ERROR
      */
-    private TestResult doBitBltCheckerBufferedImageType4ByteABGRPre(TestImage image, Graphics2D graphics2d,
+    private TestResult doBitBltCheckerBufferedImageType4ByteABGR_Pre(TestImage image, Graphics2D graphics2d,
                     Color backgroundColor)
     {
         return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE, backgroundColor);
     }
 
     /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_INT_ARGB}.
      *
      * @param image
      *            image to be used as a destination for BitBlt-type operations
@@ -371,7 +388,7 @@
     }
 
     /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB_PRE
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_INT_ARGB_PRE}.
      *
      * @param image
      *            image to be used as a destination for BitBlt-type operations
@@ -381,14 +398,14 @@
      *            background color
      * @return test result status - PASSED, FAILED or ERROR
      */
-    private TestResult doBitBltCheckerBufferedImageTypeIntARGBPre(TestImage image, Graphics2D graphics2d,
+    private TestResult doBitBltCheckerBufferedImageTypeIntARGB_Pre(TestImage image, Graphics2D graphics2d,
                     Color backgroundColor)
     {
         return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE, backgroundColor);
     }
 
     /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_BGR
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
      *
      * @param image
      *            image to be used as a destination for BitBlt-type operations
@@ -405,7 +422,7 @@
     }
 
     /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_RGB
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_INT_RGB}.
      *
      * @param image
      *            image to be used as a destination for BitBlt-type operations
@@ -422,7 +439,7 @@
     }
 
     /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_BINARY
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_BYTE_BINARY}.
      *
      * @param image
      *            image to be used as a destination for BitBlt-type operations
@@ -439,7 +456,7 @@
     }
 
     /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_GRAY
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
      *
      * @param image
      *            image to be used as a destination for BitBlt-type operations
@@ -456,7 +473,7 @@
     }
 
     /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_INDEXED
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_BYTE_INDEXED}.
      *
      * @param image
      *            image to be used as a destination for BitBlt-type operations
@@ -473,7 +490,7 @@
     }
 
     /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_555_RGB
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_USHORT_555_RGB}.
      *
      * @param image
      *            image to be used as a destination for BitBlt-type operations
@@ -490,7 +507,7 @@
     }
 
     /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_565_RGB
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_USHORT_565_RGB}.
      *
      * @param image
      *            image to be used as a destination for BitBlt-type operations
@@ -507,7 +524,7 @@
     }
 
     /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_GRAY
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_USHORT_GRAY}.
      *
      * @param image
      *            image to be used as a destination for BitBlt-type operations
@@ -116,7 +116,7 @@
 
     /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_4BYTE_ABGR
+     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_PRE}.
      *
      * @param image
@@ -303,7 +303,7 @@
 
     /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR
+     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_CUSTOM}.
      *
      * @param image
@@ -337,7 +354,7 @@
 
     /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_4BYTE_ABGR
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_PRE}.
      *
      * @param image


More information about the distro-pkg-dev mailing list